import { z } from 'zod';
import {
  routeContextBindBodyParser,
  routeContextBodyParser,
  routeContextDetailsResultParser,
  routeContextInitResultParser,
  routeContextParamsParser,
  routeContextQueryParser,
  routePacketQueryParser,
} from './parsers';
import { GraphEdgeUnit } from '../../graph/types';
import { RoutableEdgeType, RoutableNodeType } from '../../graph/routing/types';

export type PayinRouteQuery = z.infer<typeof routePacketQueryParser>;
export type PayinRouteResult = {
  endpoints: Array<{
    amt: number;
    packets: Array<{
      amt: number;
      payee: string;
      path: Array<{
        src: string;
        dst: string;
        edgeAmt: number;
        edgeUnit: GraphEdgeUnit;
        transferredAmt: number;
      }>;
    }>;
  }>;
  traces: {
    nodes: {
      uuid: string; // TODO it's a node id but we don't borrow its types; probably should be some intermediate structure
      type: RoutableNodeType;
    }[];
    edges: {
      type: RoutableEdgeType;
      src: string;
      dst: string;
    }[];
  }[];
};
export type PayinContextQuery = z.infer<typeof routeContextQueryParser>;
export type PayinContextParams = z.infer<typeof routeContextParamsParser>;
export type PayinContextDetailsResult = z.infer<typeof routeContextDetailsResultParser>;
export type PayinContextBody = z.infer<typeof routeContextBodyParser>;
export type PayinContextInitResult = z.infer<typeof routeContextInitResultParser>;
export type PayinContextBindBody = z.infer<typeof routeContextBindBodyParser>;
